@@ -141,7 +141,7 @@ The flow id is initially an empty string. As soon as the user is
 starting a new work flow or the current selection your application
 should call the method :meth:`~MainBaseApp.change_flow` passing
 the flow id string into the
-:paramref:`~MainAppBase.change_flow.flow_id` argument
+:paramref:`~MainAppBase.change_flow.new_flow_id` argument
 for to change the app flow.
 
 For more complex applications you can specify a path of nested flows.
@@ -369,7 +369,7 @@ from ae.console import ConsoleApp                   # type: ignore
 from ae.files import FilesRegister, RegisteredFile  # type: ignore
 
 
-__version__ = '0.0.22'
+__version__ = '0.0.23'
 
 
 AppStateType = Dict[str, Any]                   #: app state config variable type
@@ -594,10 +594,10 @@ class MainAppBase(ConsoleApp, ABC):
 
         self.setup_app_states(app_state)
 
-    def on_font_size_change(self, _flow_id: str, event_kwargs: Dict[str, Any]) -> bool:
+    def on_font_size_change(self, _flow_key: str, event_kwargs: Dict[str, Any]) -> bool:
         """ font size app state change event handler.
 
-        :param _flow_id:        flow id.
+        :param _flow_key:       flow key.
         :param event_kwargs:    event kwargs with key `'font_size'` containing the new font size in pixels as float.
         :return:                True for to confirm change of flow id.
         """
@@ -606,10 +606,10 @@ class MainAppBase(ConsoleApp, ABC):
         self.change_app_state('font_size', font_size)
         return True
 
-    def on_light_theme_change(self, _flow_id: str, event_kwargs: Dict[str, Any]) -> bool:
+    def on_light_theme_change(self, _flow_key: str, event_kwargs: Dict[str, Any]) -> bool:
         """ font size app state change event handler.
 
-        :param _flow_id:        flow id.
+        :param _flow_key:       flow key.
         :param event_kwargs:    event kwargs with key `'light_theme'` containing True|False for light|dark theme.
         :return:                True for to confirm change of flow id.
         """
@@ -720,19 +720,19 @@ class MainAppBase(ConsoleApp, ABC):
         """
         return stack_var(class_name)
 
-    def change_flow(self, ifi: str, popups_to_close: Sequence = (), **event_kwargs) -> bool:
+    def change_flow(self, new_flow_id: str, popups_to_close: Sequence = (), **event_kwargs) -> bool:
         """ change/switch flow id.
 
-        :param ifi:             new initial flow id (maybe overwritten by event handlers in event_kwargs['flow_id']).
+        :param new_flow_id:     new flow id (maybe overwritten by event handlers in event_kwargs['flow_id']).
         :param popups_to_close: optional sequence of widgets to be closed on confirmed flow change.
         :param event_kwargs:    optional args to pass additional data or info onto and from the event handler.
                                 info pass onto event handler:
                                     * `popup_kwargs`: optional dict passed to the Popup `__init__` method,
                                        like e.g. dict(parent=parent_widget_of_popup, data=...).
                                 info passed from the event handler:
-                                    * `flow_id`: process :attr:`~MainAppBase.flow_path` as specified by ifi,
-                                      but then overwrite initial flow id with this event arg value for to set
-                                      :attr:`~MainAppBase.flow_id`.
+                                    * `flow_id`: process :attr:`~MainAppBase.flow_path` as specified by the
+                                      :paramref:`~change_flow.new_flow_id` argument, but then overwrite this
+                                      flow id with this event arg value for to set :attr:`~MainAppBase.flow_id`.
         :return:                True if flow changed and got confirmed by a declared custom event handler
                                 (either event method or Popup class) of the app, else False.
                                 Some flow actions are handled internally independent from the
@@ -742,21 +742,21 @@ class MainAppBase(ConsoleApp, ABC):
                                 indexed widget the input focus (these exceptions are configurable via
                                 the list :data:`ACTIONS_CHANGING_FLOW_WITHOUT_CONFIRMATION`).
         """
-        self.dpo(f"MainAppBase.change_flow('{ifi}', {popups_to_close}, {event_kwargs})"
+        self.dpo(f"MainAppBase.change_flow('{new_flow_id}', {popups_to_close}, {event_kwargs})"
                  f" flow='{self.flow_id}' path={self.flow_path}")
 
-        action = flow_action(ifi)
-        if not self.call_method(flow_event_name(ifi), ifi, event_kwargs) \
-                and not self.on_flow_change(ifi, event_kwargs) \
+        action = flow_action(new_flow_id)
+        if not self.call_method(flow_event_name(new_flow_id), flow_key(new_flow_id), event_kwargs) \
+                and not self.on_flow_change(new_flow_id, event_kwargs) \
                 and action not in ACTIONS_CHANGING_FLOW_WITHOUT_CONFIRMATION:
-            self.vpo(f"MainAppBase.change_flow REJECTED '{ifi}'; flow='{self.flow_id}' path={self.flow_path}")
+            self.vpo(f"MainAppBase.change_flow REJECTED '{new_flow_id}'; flow='{self.flow_id}' path={self.flow_path}")
             return False
 
         has_flow_focus = flow_action(self.flow_id) == 'focus'
         if action in ACTIONS_EXTENDING_FLOW_PATH:
-            self.flow_path.append(ifi)
+            self.flow_path.append(new_flow_id)
             self.change_app_state('flow_path', self.flow_path)
-            flow_id = id_of_flow('', '') if action == 'enter' else ifi
+            flow_id = id_of_flow('', '') if action == 'enter' else new_flow_id
         elif action in ACTIONS_REDUCING_FLOW_PATH:
             # dismiss gets sent sometimes twice (e.g. on heavy double-clicking on drop-down-open-buttons)
             # .. therefore prevent run-time error
@@ -770,7 +770,7 @@ class MainAppBase(ConsoleApp, ABC):
             else:
                 flow_id = self.flow_id if has_flow_focus else id_of_flow('', '')
         else:
-            flow_id = ifi if action == 'focus' else (self.flow_id if has_flow_focus else id_of_flow('', ''))
+            flow_id = new_flow_id if action == 'focus' else (self.flow_id if has_flow_focus else id_of_flow('', ''))
 
         popups_to_close = event_kwargs.get('popups_to_close', popups_to_close)
         for widget in reversed(popups_to_close):
@@ -785,8 +785,8 @@ class MainAppBase(ConsoleApp, ABC):
             self.call_method('on_flow_widget_focused')
             self._last_focus_flow_id = flow_id
 
-        self.vpo(f"MainAppBase.change_flow CHANGED '{ifi}'; flow='{self.flow_id}' last='{self._last_focus_flow_id}'"
-                 f" path={self.flow_path}")
+        self.vpo(f"MainAppBase.change_flow CHANGED '{new_flow_id}';"
+                 f" flow='{self.flow_id}' last='{self._last_focus_flow_id}' path={self.flow_path}")
         return True
 
     def flow_path_action(self, path_index: int = -1) -> str:
@@ -817,7 +817,7 @@ class MainAppBase(ConsoleApp, ABC):
         return False
 
     @staticmethod
-    def on_flow_popup_close(_flow_id: str, _popup_args: Dict[str, Any]) -> bool:
+    def on_flow_popup_close(_flow_key: str, _popup_args: Dict[str, Any]) -> bool:
         """ default popup close handler of FlowPopup widget, ensuring update of :attr:`flow_path`. """
         return True
 
